netapp_ontap.models.node_metrocluster API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.node_metrocluster`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NodeMetroclusterSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NodeMetrocluster object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `custom_vlan_capable GET`

    Indicates whether the MetroCluster over IP platform supports custom VLAN IDs.

  `ports GET`

    MetroCluster over IP ports.

  `type GET`

    The Metrocluster configuration type

    Valid choices:

    - fc
    - fc_2_node
    - ip